@@ -9,14 +9,13 @@
 #include <sys/sysmacros.h>
 #elif defined(__FreeBSD__)
 #include <dev/evdev/input.h>
-#else
-#error Unsupported platform
 #endif
 
 #include "evdev.h"
 
 #define STRLEN(s) ((sizeof(s) / sizeof(s[0])) - 1)
 
+#if defined(__linux__) || defined(__FreeBSD__)
 int path_is_evdev(const char *path) {
 	static const char prefix[] = "/dev/input/event";
 	static const size_t prefixlen = STRLEN(prefix);
@@ -26,9 +25,15 @@ int path_is_evdev(const char *path) {
 int evdev_revoke(int fd) {
 	return ioctl(fd, EVIOCREVOKE, NULL);
 }
-
-#if defined(__linux__)
-int dev_is_evdev(dev_t device) {
-	return major(device) == INPUT_MAJOR;
+#elif defined(__NetBSD__)
+int path_is_evdev(const char *path) {
+	(void)path;
+	return 0;
 }
+int evdev_revoke(int fd) {
+	(void)fd;
+	return 0;
+}
+#else
+#error Unsupported platform
 #endif
